Functions
=========

.. toctree::
   :maxdepth: 3

.. automodule:: psyneulink.components.functions.function
   :members: Function_Base,
             ModulationParam,
             ArgumentTherapy,
             UserDefinedFunction,
             Reduce,
             LinearCombination,
             TransferFunction,
             Linear,
             Exponential,
             Logistic,
             SoftMax,
             LinearMatrix,
             Integrator,
             SimpleIntegrator,
             ConstantIntegrator,
             AdaptiveIntegrator,
             DriftDiffusionIntegrator,
             OrnsteinUhlenbeckIntegrator,
             FHNIntegrator,
             AGTUtilityIntegrator,
             AccumulatorIntegrator,
             LCAIntegrator,
             BogaczEtAl,
             NavarroAndFuss,
             NormalDist,
             ExponentialDist,
             UniformDist,
             GammaDist,
             WaldDist,
             Stability,
             Distance,
             LearningFunction,
             Reinforcement,
             BackPropagation,
   :exclude-members: MappingProjection, ParameterState
